@@ -524,8 +524,11 @@ class Ticker(_YahooFinance):
                 for p in ls:
                     df["dataType"] = df["dataType"].apply(lambda x: str(x).lstrip(p))
                 df["asOfDate"] = pd.to_datetime(df["asOfDate"], format="%Y-%m-%d")
+                index = ["symbol", "asOfDate", "periodType"]
+                if financials_type != "valuation":
+                    index.append("currencyCode")
                 df = df.pivot_table(
-                    index=["symbol", "asOfDate", "periodType"],
+                    index=index,
                     columns="dataType",
                     values="reportedValue",
                 )
@@ -1220,19 +1223,13 @@ class Ticker(_YahooFinance):
             historical pricing data
         """
         config = self._CONFIG["chart"]
-        periods = config["query"]["range"]["options"]
         intervals = config["query"]["interval"]["options"]
         if start or period is None or period.lower() == "max":
             start = _convert_to_timestamp(start)
             end = _convert_to_timestamp(end, start=False)
             params = {"period1": start, "period2": end}
         else:
-            period = period.lower()
-            if period not in periods:
-                raise ValueError(
-                    "Period values must be one of {}".format(", ".join(periods))
-                )
-            params = {"range": period}
+            params = {"range": period.lower()}
         if interval not in intervals:
             raise ValueError(
                 "Interval values must be one of {}".format(", ".join(intervals))
